[![License: AGPL v3](https://img.shields.io/badge/License-AGPL_v3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/a-fmm/badge/?version=latest)](https://lekkersim.readthedocs.io/en/latest/?badge=latest)

# LekkerSIM package

LekkerSIM is a open source package for linear simulation of photonic circuit, based on the well known scattering matrix method.
Its features include:
- Easy calculation of S-parameters of a photonic circuit;
- A collection of pre-defined building blocks for easy definition of circuits;
- Parametric building blocks;
- Hierarchical circuit definition;
- Monitors inside the circuit for calculation of power flow.

## Installation
You can install LekkerSIM directly from pypi by running:

    pip install lekkersim

## Documentation
Full documentation is available on [Read the Docs](https://lekkersim.readthedocs.io).